==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/72/727a9b878680aac94164b6ca4794b3db.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/SmsBundle/Assets/img/Twilio.png */
class __TwigTemplate_6e92909152e44e160809705559078b5d extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000>a\000\000 IDATx]\tGyMHXؒfk%g\000\tI&!ܘ09B^s@X\$M\"ـ%y޳OfשnWw+MOݙ{uսW^ݫ{u{oOϯtkY!~M~\t&^e~7#cu\"N;{ſq۶GVFxr]q^in؟v5o}S<d]oy5j'uY]ϯ)'n
}Zt.ڱEK:*[f8{7޷+mn΄fPs0Wy1(v0%C*
OW*=iYwjі9!gu)vaDd\\
jo.gAlQ65q6{zg=R{e%Pb}]v|1C6nN^Q0
mTs:Ƶ]`ɐRTҊ_0}^3-[_b;~
T\tv8tQ#}B#n71,%yߙg!jNHG5u~{ق/ǎ<1D?戹LX7ԙ8Pٽs^܊,*=l!O0׼})ϱ9%s9o8\\*%SDe3C6q%|@&
u3sC-X<Eu}6GL_&>\"F!:̰31^߮)=;pۼnf4-¢nV'Z\\ۙflϧWG\\O2aǧxWS~ɮD[׍`sk';e@-kpW.ktC]sOU&z\"1<meqE}?Wn\\u]EmxH_>mbK/IL2<T'ƶ24OkKܢr?ʰq̙屄%_94mBhOĀۏ&i[¸'QCo;=)TL6 jl.0[\"O.'R/Ŋ5OwUDx֒Ļ`Vﬕ-V~=SABUW\\d
kʏ:Aim@]W3^a/i!/+d,yFeU[\tb;b_O|BL}Z28\\ܿwC
ztǮ1iWqܷ,w&yxk:^~EvTla^v+;rHGOV1uAɪ)ߒ7qC3\tBWx&\\s\\%Ő*\\#ihLKǘ#Lܿ% euD̯\"&qf5]m0JH_V fA뵊m~\\0Ifػgܲ,Or&hɤʓQMA|0ߥJ>S\\2xa!Lw`bfR\"/k֭
o`M`UkSʅ%yu=A\000{!vƼu 愹6¶>Ce6MEsub-Z#)\"`~m_8i8J_08yT~I3.?F!q^d<;g>=oY060`6M߬Ug\ta\\#ҭ\"7l)Wwsl=pA
b>h }HB'Q^|xO.^~;Ĥosg*8\$a.+OfPN*sN&XDt\\
:ËO&I^T/Y
̢:|t.& ?sgb\000dFVjx>~F3.%~!^F\tQH%jy(b%d
ƅy3QYgn
sMI]z-:yNZF1jo&
c2N(S.m}Y`TdhR7k4ț>zDb(H\"YS_ߩ?A1HX-fQj\000ExkOLTТCX*pQs\\T3&t1ɤX_dDzxl@ؙgQo0_;1m)3{i`-,R 518/w?P4M.dd Ş(Nw>*pW?68ƔU;C⩕s`beh+vof~c\000fX^qYna+il¥<駈4\000Gfȓ,ADw0Ak{\$x0SSR2A^u뢹,}pcQR ^;\$'}ݺ=C;3\"HVZOu>~z~3v:D}]`v^4;6̥>Ȁm2.
hb?詳(WUF&4\t!Z`52:1Q7)M-<W̲vc spR̺FjV6'ZI#i̟3Ii[A.0.K!LlU+ܶsLB^Ş|Jw?L++`\\MY<nqDM5_-ռC#sK4-#kh'>%˹.MF>f2UQuK\"A-^]=j_]gtֲ̃us m*'n:f4Ax̄ϒGw4`s?{!_ƙ'-bXc\\J)FٚArH\\|897|D#¤9|~id)fr[;.O7.oX1tOMuIC0Z2}ILj@1le2Fx[
k4pZ̉3X=
8w)1??QƳ*&A5YTC%i5@eE1lNRxIFq7>sBn\">)Z7uDOx\\ᨬ
Kh\000601O7+!q1x}&aul~޼\$@4ʻReQtPuw
\"Ӭ˺!+y[\$&!~BvK֌Fx81D\000z]
04L+inL]=.\tcF*7@j<qϏ9d3~u;d7c`|%Х];s`Ó<1<K\"ĜvX֜kG>85B7DQ?1J6+EbVml,'y5a6]E+ǵbxŲDh6 uYI\000E@CWG:
6ҋPxWƢcвJA?Q╝z65^.(D˷,q`Ĵ&#UD)c0~L6,HX
^(g\\˞39Ԧaw\tz؜b&b<'\\)yBpoLv3N:0&Y/[I(mk*dGF!ӓ9&mҤne%4E%+fE+w25p)aQ@(!6DWӋyGGqAt!QsO}ZCO1>MB}o_K8@bLF)1%KBJ)Y41 Td>/HDOoZ,2[ǻٶ[\"##l=͢{ۍ)
ߛ@/)\000ېUX.Uf(=FWI#T^V\"#g5m4Mղfv5x5o7keM2hݡ\$0.C<c1&o3^qݽ\"DSɲ\"bANyv]3Kq^DE7[,W'wR-Bn<m/QD1%{IU066YdDCiXlHhrr!o+|vpCia8N#Vrtp矘]Eш\000Mzw\$O,CuCWp8D\000xT&\t*k=o.r1Ն[bt\"M\000\000/\000^ܔf\000Cw#=^c\000ZYJ\000lWGeWv]蜜\000H:\0006}Ğ8k1;U2\000G,Mf`FjT!6\000@Q,؝#KlӭjHB󄺈q\\&b7Y@)u-p1b8Sְ({
yPcICYoogbuoA38 4,RY0o0\$Y7˺o]-d
g\tflGxY\\-0h*&\t\\R.@dјAҚf\t2]T0^b
7eU,QRj{Ϋ㙺g3:^~g'/2~y%T6_Ĉ{n3&I@@CX\0005/^R }~~gD[3d(!dq]#rbYfҹ\\wNCydϺM
~ГxH1D0O3gAWd
}pPx\"LddIjΞ?\000SNe*ԴV~=6ϻ%1u/yCYC܌\\ AUi%R8QfT})\tF@yY<Q}ٌTPeUWdE eԿ(+0}q|֍ٚ˫\0009F4Q)]t@WkXy\000!(K05g;pF̇\"0_\000
Rq=KY쁰/2[>7SK0ih!E̀
F;uEtI9TIC\t<?\"g?4:w\$MMvC\$Ď'4,/N\\,8R@Y3g5aBh-_
ƩqBaD@iQX8)O?Upq(I.&`;\"hI\000(|dՒ˛EvC\000QO\000`f;T߉h;PֽuRebH(TUb;>tT#VABΛJV}
?@R'CuIb&{\\T\$tfS/?N~YuϤ&_ 4ڑxtAPn8) REiX@GIzC}[Tvi{;Z[Չ\000P8`[Fvhh1+iVA8 5䔍Ш~(e?!`Ɂ85`j3šA@Ə)ga^\$LYѽbRt
ۣP.3dӤV޸DiᘺYa9m5Cl}dhQEP|5>I
pi4.8eS psd\000ŰNe탼Aq7\$,%9lfwδ>IdPM11m~T&۹F臰T)]
 \"~BWsg# Ise\"I#ɣZѾ(jWLZıpG#mSoe._=%ˍGE1e\tBr[d>/neܕTƭmӎA?5ٜAM2>
KP<kx`}}#r s2\$)nQkrX&7v<)d] #
d6
ŋa0D[_['C]<̻03'm:sHXcQ*klQ[*=SaTp*K5JB~-2mj[ԁxTg4EK(C
AU0Bk]Y|̩u\\ Q\0000)&C|amdnbՏHR_B
nj!cU%N
qxg88AWp~PfT<Ы\$1vp/JFcaMiB=XE'];VY&B)6c*
10=+Ϡgxv{J%
<\000U>=.CN۴c!oztO-<G],ǸL[%Yp[.z*
:U:yUyphxG,(m;SU{\tF\t+֑fäq+k,q(7Ǐ+h~cכ1;sZIUܡn!RL4\"0ˇŊ|z+hč<n]P&zI=]Q+BmyLaHě+y88I .ؑosY5Ua5s9+\$X^JOO[<8hhV3!:VwNDVV&>Tyl1beGSىa9MsU7~ka-|P9ٟGQxHx7fBEڕ)~q1&
L\000uuFD1im=P\tW4xgYas77khTm&F؛܊{\tIG<,k8veݶC-[jhǝ0(~5Cu\000ODK_\tXF%O5Ο)ȲEy VN߽-C1]xFfwQH~w,W\0007-#cDЗ0ء3H2Fm&\"HrxI7=T׭+h'Qw+P-d\$IВTZ1/Ux>3 
+,5j6{,Ќ@\$<h%WMNCu3cDphUQw3
3nEv圀,~?Hpx\tř\$3odM*77B@[jA%@~4\000V<+ֹ &B8Ff?yLO~~8F}|oh\t;W遝iQ^Lj0|E@yf-
^þ73yz%(\".w ?l'^ڻC\t|]ic+HMawMG{+sfډ9hbW;Ŏf[>\"`d1\\ֲW&*2û@v|Nq7w5Z#lK|2L@pR\tf*<47Ii:`J»/:IR+[DЯ?^~<\"ӭw&:yc,ph5<+^&\$~惲q>DJK#>a٪e3{+~^ٸF{ةt\000~`U\\\"Ud-IFݮb}񇄕s^Iߘ:XvGe;xE5N}O1u'#ڎ
4kj4〖ۙrMuS~ׯ'
bt0Ta]n9S8k\"/FIŃ#\"u\\-\t*FT\tOpf %Q|qt99rWxpi-]^>w &.(EItbrvz3x; ns(?P?gfFPC1^.I/!q(?_S+0}{JO0c.K6o\000\t Mbl`\tXܼ8_1ɜC^;+D?1t3NCV
g6T;\\\000v.8P.!7t\"Xw=؀vҜ[hLu`Ʒzؽ*:+ӆ3\000׋h{uսֿA9R^>\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/SmsBundle/Assets/img/Twilio.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/SmsBundle/Assets/img/Twilio.png", "/var/www/mautic-ktn/app/bundles/SmsBundle/Assets/img/Twilio.png");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/72/727a9b878680aac94164b6ca4794b3db.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/SmsBundle/Assets/img/Twilio.png */
class __TwigTemplate_6e92909152e44e160809705559078b5d extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000>a\000\000 IDATx]\tGyMHXؒfk%g\000\tI&!ܘ09B^s@X\$M\"ـ%y޳OfשnWw+MOݙ{uսW^ݫ{u{oOϯtkY!~M~\t&^e~7#cu\"N;{ſq۶GVFxr]q^in؟v5o}S<d]oy5j'uY]ϯ)'n
}Zt.ڱEK:*[f8{7޷+mn΄fPs0Wy1(v0%C*
OW*=iYwjі9!gu)vaDd\\
jo.gAlQ65q6{zg=R{e%Pb}]v|1C6nN^Q0
mTs:Ƶ]`ɐRTҊ_0}^3-[_b;~
T\tv8tQ#}B#n71,%yߙg!jNHG5u~{ق/ǎ<1D?戹LX7ԙ8Pٽs^܊,*=l!O0׼})ϱ9%s9o8\\*%SDe3C6q%|@&
u3sC-X<Eu}6GL_&>\"F!:̰31^߮)=;pۼnf4-¢nV'Z\\ۙflϧWG\\O2aǧxWS~ɮD[׍`sk';e@-kpW.ktC]sOU&z\"1<meqE}?Wn\\u]EmxH_>mbK/IL2<T'ƶ24OkKܢr?ʰq̙屄%_94mBhOĀۏ&i[¸'QCo;=)TL6 jl.0[\"O.'R/Ŋ5OwUDx֒Ļ`Vﬕ-V~=SABUW\\d
kʏ:Aim@]W3^a/i!/+d,yFeU[\tb;b_O|BL}Z28\\ܿwC
ztǮ1iWqܷ,w&yxk:^~EvTla^v+;rHGOV1uAɪ)ߒ7qC3\tBWx&\\s\\%Ő*\\#ihLKǘ#Lܿ% euD̯\"&qf5]m0JH_V fA뵊m~\\0Ifػgܲ,Or&hɤʓQMA|0ߥJ>S\\2xa!Lw`bfR\"/k֭
o`M`UkSʅ%yu=A\000{!vƼu 愹6¶>Ce6MEsub-Z#)\"`~m_8i8J_08yT~I3.?F!q^d<;g>=oY060`6M߬Ug\ta\\#ҭ\"7l)Wwsl=pA
b>h }HB'Q^|xO.^~;Ĥosg*8\$a.+OfPN*sN&XDt\\
:ËO&I^T/Y
̢:|t.& ?sgb\000dFVjx>~F3.%~!^F\tQH%jy(b%d
ƅy3QYgn
sMI]z-:yNZF1jo&
c2N(S.m}Y`TdhR7k4ț>zDb(H\"YS_ߩ?A1HX-fQj\000ExkOLTТCX*pQs\\T3&t1ɤX_dDzxl@ؙgQo0_;1m)3{i`-,R 518/w?P4M.dd Ş(Nw>*pW?68ƔU;C⩕s`beh+vof~c\000fX^qYna+il¥<駈4\000Gfȓ,ADw0Ak{\$x0SSR2A^u뢹,}pcQR ^;\$'}ݺ=C;3\"HVZOu>~z~3v:D}]`v^4;6̥>Ȁm2.
hb?詳(WUF&4\t!Z`52:1Q7)M-<W̲vc spR̺FjV6'ZI#i̟3Ii[A.0.K!LlU+ܶsLB^Ş|Jw?L++`\\MY<nqDM5_-ռC#sK4-#kh'>%˹.MF>f2UQuK\"A-^]=j_]gtֲ̃us m*'n:f4Ax̄ϒGw4`s?{!_ƙ'-bXc\\J)FٚArH\\|897|D#¤9|~id)fr[;.O7.oX1tOMuIC0Z2}ILj@1le2Fx[
k4pZ̉3X=
8w)1??QƳ*&A5YTC%i5@eE1lNRxIFq7>sBn\">)Z7uDOx\\ᨬ
Kh\000601O7+!q1x}&aul~޼\$@4ʻReQtPuw
\"Ӭ˺!+y[\$&!~BvK֌Fx81D\000z]
04L+inL]=.\tcF*7@j<qϏ9d3~u;d7c`|%Х];s`Ó<1<K\"ĜvX֜kG>85B7DQ?1J6+EbVml,'y5a6]E+ǵbxŲDh6 uYI\000E@CWG:
6ҋPxWƢcвJA?Q╝z65^.(D˷,q`Ĵ&#UD)c0~L6,HX
^(g\\˞39Ԧaw\tz؜b&b<'\\)yBpoLv3N:0&Y/[I(mk*dGF!ӓ9&mҤne%4E%+fE+w25p)aQ@(!6DWӋyGGqAt!QsO}ZCO1>MB}o_K8@bLF)1%KBJ)Y41 Td>/HDOoZ,2[ǻٶ[\"##l=͢{ۍ)
ߛ@/)\000ېUX.Uf(=FWI#T^V\"#g5m4Mղfv5x5o7keM2hݡ\$0.C<c1&o3^qݽ\"DSɲ\"bANyv]3Kq^DE7[,W'wR-Bn<m/QD1%{IU066YdDCiXlHhrr!o+|vpCia8N#Vrtp矘]Eш\000Mzw\$O,CuCWp8D\000xT&\t*k=o.r1Ն[bt\"M\000\000/\000^ܔf\000Cw#=^c\000ZYJ\000lWGeWv]蜜\000H:\0006}Ğ8k1;U2\000G,Mf`FjT!6\000@Q,؝#KlӭjHB󄺈q\\&b7Y@)u-p1b8Sְ({
yPcICYoogbuoA38 4,RY0o0\$Y7˺o]-d
g\tflGxY\\-0h*&\t\\R.@dјAҚf\t2]T0^b
7eU,QRj{Ϋ㙺g3:^~g'/2~y%T6_Ĉ{n3&I@@CX\0005/^R }~~gD[3d(!dq]#rbYfҹ\\wNCydϺM
~ГxH1D0O3gAWd
}pPx\"LddIjΞ?\000SNe*ԴV~=6ϻ%1u/yCYC܌\\ AUi%R8QfT})\tF@yY<Q}ٌTPeUWdE eԿ(+0}q|֍ٚ˫\0009F4Q)]t@WkXy\000!(K05g;pF̇\"0_\000
Rq=KY쁰/2[>7SK0ih!E̀
F;uEtI9TIC\t<?\"g?4:w\$MMvC\$Ď'4,/N\\,8R@Y3g5aBh-_
ƩqBaD@iQX8)O?Upq(I.&`;\"hI\000(|dՒ˛EvC\000QO\000`f;T߉h;PֽuRebH(TUb;>tT#VABΛJV}
?@R'CuIb&{\\T\$tfS/?N~YuϤ&_ 4ڑxtAPn8) REiX@GIzC}[Tvi{;Z[Չ\000P8`[Fvhh1+iVA8 5䔍Ш~(e?!`Ɂ85`j3šA@Ə)ga^\$LYѽbRt
ۣP.3dӤV޸DiᘺYa9m5Cl}dhQEP|5>I
pi4.8eS psd\000ŰNe탼Aq7\$,%9lfwδ>IdPM11m~T&۹F臰T)]
 \"~BWsg# Ise\"I#ɣZѾ(jWLZıpG#mSoe._=%ˍGE1e\tBr[d>/neܕTƭmӎA?5ٜAM2>
KP<kx`}}#r s2\$)nQkrX&7v<)d] #
d6
ŋa0D[_['C]<̻03'm:sHXcQ*klQ[*=SaTp*K5JB~-2mj[ԁxTg4EK(C
AU0Bk]Y|̩u\\ Q\0000)&C|amdnbՏHR_B
nj!cU%N
qxg88AWp~PfT<Ы\$1vp/JFcaMiB=XE'];VY&B)6c*
10=+Ϡgxv{J%
<\000U>=.CN۴c!oztO-<G],ǸL[%Yp[.z*
:U:yUyphxG,(m;SU{\tF\t+֑fäq+k,q(7Ǐ+h~cכ1;sZIUܡn!RL4\"0ˇŊ|z+hč<n]P&zI=]Q+BmyLaHě+y88I .ؑosY5Ua5s9+\$X^JOO[<8hhV3!:VwNDVV&>Tyl1beGSىa9MsU7~ka-|P9ٟGQxHx7fBEڕ)~q1&
L\000uuFD1im=P\tW4xgYas77khTm&F؛܊{\tIG<,k8veݶC-[jhǝ0(~5Cu\000ODK_\tXF%O5Ο)ȲEy VN߽-C1]xFfwQH~w,W\0007-#cDЗ0ء3H2Fm&\"HrxI7=T׭+h'Qw+P-d\$IВTZ1/Ux>3 
+,5j6{,Ќ@\$<h%WMNCu3cDphUQw3
3nEv圀,~?Hpx\tř\$3odM*77B@[jA%@~4\000V<+ֹ &B8Ff?yLO~~8F}|oh\t;W遝iQ^Lj0|E@yf-
^þ73yz%(\".w ?l'^ڻC\t|]ic+HMawMG{+sfډ9hbW;Ŏf[>\"`d1\\ֲW&*2û@v|Nq7w5Z#lK|2L@pR\tf*<47Ii:`J»/:IR+[DЯ?^~<\"ӭw&:yc,ph5<+^&\$~惲q>DJK#>a٪e3{+~^ٸF{ةt\000~`U\\\"Ud-IFݮb}񇄕s^Iߘ:XvGe;xE5N}O1u'#ڎ
4kj4〖ۙrMuS~ׯ'
bt0Ta]n9S8k\"/FIŃ#\"u\\-\t*FT\tOpf %Q|qt99rWxpi-]^>w &.(EItbrvz3x; ns(?P?gfFPC1^.I/!q(?_S+0}{JO0c.K6o\000\t Mbl`\tXܼ8_1ɜC^;+D?1t3NCV
g6T;\\\000v.8P.!7t\"Xw=؀vҜ[hLu`Ʒzؽ*:+ӆ3\000׋h{uսֿA9R^>\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/SmsBundle/Assets/img/Twilio.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/SmsBundle/Assets/img/Twilio.png", "/var/www/html/mauticGIT-Test/app/bundles/SmsBundle/Assets/img/Twilio.png");
    }
}
